# Copied from the echo_kernel example:
# https://github.com/jupyter/echo_kernel/blob/master/echo_kernel/install.py
#!/usr/bin/python3
import argparse
import json
import os
import sys

from jupyter_client.kernelspec import KernelSpecManager
from IPython.utils.tempdir import TemporaryDirectory

kernel_json = {
    "argv": [sys.executable, "-m", "elm_kernel", "-f", "{connection_file}"],
    "display_name": "Elm",
    "language": "elm",
}


def install_my_kernel_spec(user=True, prefix=None):
    with TemporaryDirectory() as td:
        os.chmod(td, 0o755)  # Starts off as 700, not user readable
        with open(os.path.join(td, 'kernel.json'), 'w') as f:
            json.dump(kernel_json, f, sort_keys=True)

        print('Installing Jupyter kernel spec')
        ksm = KernelSpecManager()
        ksm.install_kernel_spec(
            td, 'elm', user=user, prefix=prefix)

        install_dir = ksm.get_kernel_spec(kernel_name="elm").resource_dir

        print("Installed to ", install_dir)


def _is_root():
    try:
        return os.geteuid() == 0
    except AttributeError:
        return False  # assume not an admin on non-Unix platforms


def main(argv=None):
    ap = argparse.ArgumentParser()
    ap.add_argument(
        '--user', action='store_true',
        help="Install to the per-user kernels registry. Default if not root.")
    ap.add_argument(
        '--sys-prefix', action='store_true',
        help="Install to sys.prefix (e.g. a virtualenv or conda env)")
    ap.add_argument(
        '--prefix',
        help="Install to the given prefix. "
        "Kernelspec will be installed in {PREFIX}/share/jupyter/kernels/")
    args = ap.parse_args(argv)

    if args.sys_prefix:
        args.prefix = sys.prefix
    if not args.prefix and not _is_root():
        args.user = True

    if args.user:
        print("Elm Kernel will be Installed to per-user jupyter kernel registry.")
    else:
        print("Elm Kernel will be Installed to global jupyter kernel registry.")

    install_my_kernel_spec(user=args.user, prefix=args.prefix)


if __name__ == '__main__':
    main(sys.argv[1:])
